@@ -310,7 +310,7 @@ def fill_seniority_column(df):
 
 
 def filter_countries(df, countries,fixed_filter):
-    if fixed_filter:
+    if fixed_filter==1:
         logger.info(f'countries out of top 10 go to other')
         top = df['Country'].value_counts().head(10).index.tolist()
         df.loc[~df['Country'].isin(top),'Country'] = 'other'
@@ -322,6 +322,7 @@ def filter_countries(df, countries,fixed_filter):
     return df
 
 
+
 def convert_kwkey_specialties_and_technologies_to_int(df):
     """Using regular expressions, converts a comma separated list of keys and technologies into the number of elements of this columns
 
